@@ -4,7 +4,6 @@ from datetime import datetime
 from MSApi.documents import DocumentMS, check_init
 from MSApi.MSLowApi import MSLowApi, error_handler, caching
 from MSApi.State import State
-from MSApi.documents import ProcessingOrder
 
 
 class Processing(DocumentMS):
@@ -15,7 +14,7 @@ class Processing(DocumentMS):
         return MSLowApi.gen_objects('entity/processing', Processing, **kwargs)
 
     @classmethod
-    def get_template_by_processing_order(cls, processing_order: ProcessingOrder, **kwargs):
+    def get_template_by_processing_order(cls, processing_order, **kwargs):
         json_data = {
             "processingOrder": {
                 "meta": processing_order.get_meta().get_json()
