@@ -7,7 +7,8 @@ from MSApi.State import State
 from MSApi.Organization import Account
 from MSApi.Project import Project
 from MSApi.Attribute import Attribute
-from MSApi.documents import Processing, ProcessingPlan
+from MSApi.documents.Processing import Processing
+from MSApi.documents.ProcessingPlan import ProcessingPlan
 
 
 class ProcessingOrder(ObjectMS):
